@@ -1,6 +1,6 @@
 #import <math.h>
 #import <graph.h>
-#import <boolnet.h>
+#import <booleannet.h>
 #import <random.h>
 #import <activity.h>
 #import <collections.h>
